@@ -22,5 +22,5 @@ var functions_dup =
     [ "u", "functions_u.html", null ],
     [ "v", "functions_v.html", null ],
     [ "w", "functions_w.html", null ],
-    [ "~", "functions_0x7e.html", null ]
+    [ "~", "functions_~.html", null ]
 ];
\ No newline at end of file
